==> hyades.ies.sdk.3.0.0_20040331_1118.zip: org/eclipse/hyades/test/ui/datapool/internal/action/DeleteRowGroupAction.java <==
/*******************************************************************************
 * Copyright (c) 2003 Hyades project.
 * All rights reserved. This program and the accompanying materials 
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
package org.eclipse.hyades.test.ui.datapool.internal.action;

import org.eclipse.hyades.test.ui.datapool.DatapoolPlugin;
import org.eclipse.hyades.test.ui.datapool.internal.control.DatapoolTable;
import org.eclipse.hyades.test.ui.datapool.internal.util.ContextIds;
import org.eclipse.jface.viewers.ISelectionProvider;
import org.eclipse.ui.actions.SelectionProviderAction;
import org.eclipse.ui.help.WorkbenchHelp;

/**
 * @author psun
 *
 * To change the template for this generated type comment go to
 * Window&gt;Preferences&gt;Java&gt;Code Generation&gt;Code and Comments
 */
public class DeleteRowGroupAction extends SelectionProviderAction {
	private DatapoolTable table;

	public DeleteRowGroupAction(ISelectionProvider viewer, DatapoolTable table)
	{
		super(viewer, DatapoolPlugin.getResourceString("DEL_ROW_GRP_TEXT"));
		setDescription(DatapoolPlugin.getResourceString("DEL_ROW_GRP_LDESC"));
		WorkbenchHelp.setHelp(this, DatapoolPlugin.getID() + ContextIds.DEL_ROW_GRP_ACT);
		this.table = table;
	}

	public void run()
	{
		if (table != null)
			table.deleteRowGroup();
	}

	public void aboutToShow(boolean bShow)
	{
		setEnabled(bShow);
	}
	
}

==> hyades.ies.sdk.3.0.1.1_20040930_1148.zip: org/eclipse/hyades/test/ui/datapool/internal/action/DeleteRowGroupAction.java <==
/*******************************************************************************
 * Copyright (c) 2003, 2004 Hyades project.
 * All rights reserved. This program and the accompanying materials 
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
package org.eclipse.hyades.test.ui.datapool.internal.action;

import org.eclipse.hyades.test.ui.datapool.DatapoolPlugin;
import org.eclipse.hyades.test.ui.datapool.internal.control.DatapoolTable;
import org.eclipse.hyades.test.ui.datapool.internal.util.ContextIds;
import org.eclipse.jface.viewers.ISelectionProvider;
import org.eclipse.ui.actions.SelectionProviderAction;
import org.eclipse.ui.help.WorkbenchHelp;

/**
 * @author psun
 *
 */
public class DeleteRowGroupAction extends SelectionProviderAction {
	private DatapoolTable table;

	public DeleteRowGroupAction(ISelectionProvider viewer, DatapoolTable table)
	{
		super(viewer, DatapoolPlugin.getResourceString("DEL_ROW_GRP_TEXT")); //$NON-NLS-1$
		setDescription(DatapoolPlugin.getResourceString("DEL_ROW_GRP_LDESC")); //$NON-NLS-1$
		WorkbenchHelp.setHelp(this, DatapoolPlugin.getID() + ContextIds.DEL_ROW_GRP_ACT);
		this.table = table;
	}

	public void run()
	{
		if (table != null)
			table.deleteRowGroup();
	}

	public void aboutToShow(boolean bShow)
	{
		setEnabled(bShow);
	}
	
}
